@@ -2,7 +2,7 @@ from ptypes import Point, Rect
 import config
 import curses
 import os
-
+from version import get_version
 
 class Dialog(object):
     def __init__(self, width, height):
@@ -48,7 +48,7 @@ class AboutDialog(Dialog):
     def draw(self, app):
         super(AboutDialog, self).draw(app)
         pos = self.rect.tl + Point(4, 3)
-        lines = ('Yet Another Text EDitor',
+        lines = (f'Yet Another Text EDitor {get_version()}',
                  '',
                  'A terminal based text editor, ',
                  'inspired by a wish to have',
